#!/usr/local/bin/perl

use DAL;
use SAS;
use strict;

my $fitsfile=""; 
my $chkdir   = "";  
my $valid_log = ""; 
my $invalid_log = "";
my $vverbosity = 0;

sub dpssvali{
$fitsfile=stringParameter("set");
$chkdir=stringParameter("checkdir");
$valid_log=stringParameter("validlog");
$invalid_log=stringParameter("invalidlog");
# $vverbosity=$SAS::AppMsg;
# print "VERBOSITY = $vverbosity\n";



unless (-r $fitsfile) {

    SAS::error("ARG_INPUT", "Dataset '$fitsfile' not readable");
}
unless (-d $chkdir) {
    SAS::error("ARG_CHKDIR", "Directory '$chkdir' for tests not found");
}

open VLOG, ">> $valid_log" or
	 SAS::error("OPVAL", "Can't open valid_log '$valid_log': $!");
open ILOG, ">> $invalid_log" or
	 SAS::error("OPIVAL", "Can't open invalid_log '$invalid_log': $!");

  print "in=$fitsfile\nDir=$chkdir\nval=$valid_log\ninval=$invalid_log\n";


my @chkfiles = determine_checks($fitsfile);
unless (@chkfiles) {
    SAS::error("NOCHKS", "Can't determine checks for file: '$fitsfile'\n");
}

my @failed = check_fitsfile($fitsfile, @chkfiles);
if (@failed) {
   SAS::warning("FAIL", "File '$fitsfile' failed the following tests: " .
		join(', ', @failed) . "\n");
} else {
   exit 0;
}
}

sub determine_checks {
    my $file = shift;

    $file =~ s|.*/||;
    my $t6;
    # here real algorithm for checkfiles ... use dummys now
    if ( $file =~ /^P\d{10}\w\w\w\d{3}(\w{6})\d{4}\.\w{3}$/) {
      $t6 = lc($1);
    } else {
        SAS::error("WRGNAM", "Filename does not comply to naming convention: '$file'\n");
    }

    my @chks = ();
    @chks = $chkdir . '/expmap.chk'   if $t6 eq 'expmap';
    @chks = $chkdir . '/bkgmap.chk'   if $t6 eq 'bkgmap';
    @chks = $chkdir . '/exsnmp.chk'   if $t6 eq 'obsnmp';
#   @chks = $chkdir . '/image.chk'    if $t6 =~ /image_|oimage/;
    @chks = $chkdir . '/image.chk'    if $t6 eq 'image_';
    @chks = $chkdir . '/mod8mp.chk'   if $t6 eq 'mod8mp';
    @chks = $chkdir . '/flafld.chk'   if $t6 eq 'flafld';
    @chks = $chkdir . '/imageom.chk'  if $t6 eq 'simage';
    @chks = $chkdir . '/omsrli.chk'   if $t6 eq 'emsrli';
    @chks = $chkdir . '/obsrls.chk'   if $t6 eq 'obsrls';
    @chks = $chkdir . '/swsrli.chk'   if $t6 eq 'swsrli';

    @chks;
} 

sub check_fitsfile {
    my $file = shift;
    my (@checks) = @_; 

    my @failed_tests;
    foreach my $chkfile ( @checks ) {
       unless ( -r $chkfile ) {
            SAS::error("MISCHECK", "Checkfile '$chkfile' not readable or missing\n");
       }
#      system "dscheck --set=$file --checkfile=$chkfile -V $vverbosity"
       system "dscheck --set=$file --checkfile=$chkfile"
	    and push @failed_tests, $chkfile;
    }

    if (@failed_tests) {
       print ILOG "$fitsfile: ", join(', ', @failed_tests), "\n";
    } else {
       print VLOG "$fitsfile", "\n";
    }
    return @failed_tests
}
